var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { isVue2, Vue2, markRaw } from 'vue-demi';
import { createModuleLoader } from './core/moduleLoader';
import { createComponentLoader } from './core/componentLoader';
import { ModuleLoaderSymbol, setActiveLoader, setOptions, addErrorHandler, removeErrorHandler } from './register';
import { umdResolver, cjsResolver } from './resolvers';
/**
 * create module loader
 * @param resolver remote module resolver, default to umd resolver
 */
export function createLoader(resolver) {
    var _resolver = __assign({ isServer: isVue2 ? Vue2.prototype.$isServer : false, browser: function () { return umdResolver; }, server: function () { return cjsResolver; } }, resolver);
    var loader = markRaw({
        install: function (app) {
            // this allows calling registerSubModules() outside of a component setup after
            setActiveLoader(loader);
            if (!isVue2) {
                var moduleLoader = createModuleLoader(app, _resolver);
                var componentLoader = createComponentLoader(app, _resolver);
                loader._a = app;
                loader._moduleLoader = moduleLoader;
                loader._componentLoader = componentLoader;
                app.config.globalProperties.$moduleLoader = loader;
                app.provide(ModuleLoaderSymbol, loader);
            }
        },
        setOptions: function (options) {
            setOptions.call(null, options);
            return this;
        },
        addErrorHandler: function (handler) {
            addErrorHandler.call(null, handler);
            return this;
        },
        removeErrorHandler: function (handler) {
            removeErrorHandler.call(null, handler);
            return this;
        },
        resolver: Object.freeze(_resolver),
        // it's actually undefined here
        // @ts-expect-error set in install when using Vue 3
        _a: null,
        // @ts-expect-error set in install when using Vue 3
        _moduleLoader: null,
        // @ts-expect-error set in install when using Vue 3
        _componentLoader: null,
    });
    return loader;
}
