"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLoader = void 0;
var vue_demi_1 = require("vue-demi");
var moduleLoader_1 = require("./core/moduleLoader");
var componentLoader_1 = require("./core/componentLoader");
var register_1 = require("./register");
var resolvers_1 = require("./resolvers");
/**
 * create module loader
 * @param resolver remote module resolver, default to umd resolver
 */
function createLoader(resolver) {
    var _resolver = __assign({ isServer: vue_demi_1.isVue2 ? vue_demi_1.Vue2.prototype.$isServer : false, browser: function () { return resolvers_1.umdResolver; }, server: function () { return resolvers_1.cjsResolver; } }, resolver);
    var loader = (0, vue_demi_1.markRaw)({
        install: function (app) {
            // this allows calling registerSubModules() outside of a component setup after
            (0, register_1.setActiveLoader)(loader);
            if (!vue_demi_1.isVue2) {
                var moduleLoader = (0, moduleLoader_1.createModuleLoader)(app, _resolver);
                var componentLoader = (0, componentLoader_1.createComponentLoader)(app, _resolver);
                loader._a = app;
                loader._moduleLoader = moduleLoader;
                loader._componentLoader = componentLoader;
                app.config.globalProperties.$moduleLoader = loader;
                app.provide(register_1.ModuleLoaderSymbol, loader);
            }
        },
        setOptions: function (options) {
            register_1.setOptions.call(null, options);
            return this;
        },
        addErrorHandler: function (handler) {
            register_1.addErrorHandler.call(null, handler);
            return this;
        },
        removeErrorHandler: function (handler) {
            register_1.removeErrorHandler.call(null, handler);
            return this;
        },
        resolver: Object.freeze(_resolver),
        // it's actually undefined here
        // @ts-expect-error set in install when using Vue 3
        _a: null,
        // @ts-expect-error set in install when using Vue 3
        _moduleLoader: null,
        // @ts-expect-error set in install when using Vue 3
        _componentLoader: null,
    });
    return loader;
}
exports.createLoader = createLoader;
